What’s new in version 1.2.15
============================
Version available since January 10th 2023


Bug fixed
---------

- Call to jax Array type deleted to avoid issues with Jax different versions.

Contributors
------------
Lucas Agobert
